@@ -21,11 +21,15 @@
 #define __GSM_UTIL_H__
 
 #include <glib.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
-char *      gsm_util_find_desktop_file_for_app_name (const char  *app_name,
-                                                     char       **dirs);
+#define IS_STRING_EMPTY(x) ((x)==NULL||(x)[0]=='\0')
+
+char *      gsm_util_find_desktop_file_for_app_name (const char *app_name,
+                                                     gboolean    look_in_saved_session,
+                                                     gboolean    autostart_first);
 
 gchar      *gsm_util_get_empty_tmp_session_dir      (void);
 
@@ -35,7 +39,8 @@ gchar**     gsm_util_get_app_dirs                   (void);
 
 gchar**     gsm_util_get_autostart_dirs             (void);
 
-gchar **    gsm_util_get_desktop_dirs               (void);
+gchar **    gsm_util_get_desktop_dirs               (gboolean include_saved_session,
+                                                     gboolean autostart_first);
 
 gboolean    gsm_util_text_is_blank                  (const char *str);
 
@@ -47,6 +52,8 @@ char *      gsm_util_generate_startup_id            (void);
 void        gsm_util_setenv                         (const char *variable,
                                                      const char *value);
 
+GtkIconSize gsm_util_get_computer_fail_icon_size    (void);
+
 G_END_DECLS
 
 #endif /* __GSM_UTIL_H__ */
